==> aria2_0.12.1.orig.tar.gz: aria2-0.12.1/src/BtRejectMessageValidator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_REJECT_MESSAGE_VALIDATOR_H_
#define _D_BT_REJECT_MESSAGE_VALIDATOR_H_

#include "BtMessageValidator.h"
#include "BtRejectMessage.h"

class BtRejectMessageValidator : public BtMessageValidator {
private:
  const BtRejectMessage* message;
  int32_t numPiece;
  int32_t pieceLength;
public:
  BtRejectMessageValidator(const BtRejectMessage* message,
			   int32_t numPiece,
			   int32_t pieceLength):
    message(message),
    numPiece(numPiece),
    pieceLength(pieceLength) {}

  virtual bool validate(Errors& error) {
    // TODO
    PeerMessageUtil::checkIndex(message->getIndex(), numPiece);
    PeerMessageUtil::checkBegin(message->getBegin(), pieceLength);
    PeerMessageUtil::checkLength(message->getLength());
    PeerMessageUtil::checkRange(message->getBegin(),
				message->getLength(),
				pieceLength);
    return true;
  }
};

typedef SharedHandle<BtRejectMessageValidator> BtRejectMessageValidatorHandle;

#endif // _D_BT_REJECT_MESSAGE_VALIDATOR_H_

==> aria2_1.1.2.orig.tar.gz: aria2-1.1.2/src/BtRejectMessageValidator.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_BT_REJECT_MESSAGE_VALIDATOR_H_
#define _D_BT_REJECT_MESSAGE_VALIDATOR_H_

#include "BtMessageValidator.h"
#include "BtRejectMessage.h"
#include "PeerMessageUtil.h"

namespace aria2 {

class BtRejectMessageValidator : public BtMessageValidator {
private:
  const BtRejectMessage* message;
  size_t numPiece;
  size_t pieceLength;
public:
  BtRejectMessageValidator(const BtRejectMessage* message,
			   size_t numPiece,
			   size_t pieceLength):
    message(message),
    numPiece(numPiece),
    pieceLength(pieceLength) {}

  virtual bool validate(Errors& error) {
    // TODO
    PeerMessageUtil::checkIndex(message->getIndex(), numPiece);
    PeerMessageUtil::checkBegin(message->getBegin(), pieceLength);
    PeerMessageUtil::checkLength(message->getLength());
    PeerMessageUtil::checkRange(message->getBegin(),
				message->getLength(),
				pieceLength);
    return true;
  }
};

typedef SharedHandle<BtRejectMessageValidator> BtRejectMessageValidatorHandle;

} // namespace aria2

#endif // _D_BT_REJECT_MESSAGE_VALIDATOR_H_
